PyTables Cookbook — PyTables 3.1.1 documentation

### Navigation

- index
- modules
- modules
- next
- previous
- PyTables 3.1.1 documentation »

# PyTables Cookbook

## Contents

- Hints for SQL users
- PyTables & py2exe Howto (by Tommy Edvardsen)
- How to install PyTables when you’re not root (by Koen van de Sande)
- Tailoring atexit hooks
- Using your own custom data types
- SimpleTable: simple wrapper around the Table object
- In-memory HDF5 files

### Navigation

- index
- modules
- modules
- next
- previous
- PyTables 3.1.1 documentation »